Learn R Programming

phenofit (version 0.2.0)

fprintf: fprintf Print sprintf result into console, just like C style fprintf function

Description

fprintf Print sprintf result into console, just like C style fprintf function

print the running ID in the console

Usage

fprintf(fmt, ...)

runningId(i, step = 1, prefix = "")

Arguments

fmt

a character vector of format strings, each of up to 8192 bytes.

...

other parameters will be passed to sprintf

i

the running Id.

step

how long of print step.

prefix

prefix string

Examples

Run this code
# NOT RUN {
cat(fprintf("%s\n", "Hello phenofit!"))
for (i in 1:10){
    runningId(i, prefix = "phenofit")
}
# }

Run the code above in your browser using DataLab