powered by
fprintf Print sprintf result into console, just like C style fprintf function
print the running ID in the console
fprintf(fmt, ...)runningId(i, step = 1, prefix = "")
runningId(i, step = 1, prefix = "")
a character vector of format strings, each of up to 8192 bytes.
other parameters will be passed to sprintf
sprintf
the running Id.
how long of print step.
prefix string
# NOT RUN { cat(fprintf("%s\n", "Hello phenofit!")) for (i in 1:10){ runningId(i, prefix = "phenofit") } # }
Run the code above in your browser using DataLab